################
lsst-ctrl-mpexec
################

.. image:: https://img.shields.io/pypi/v/lsst-ctrl-mpexec.svg
    :target: https://pypi.org/project/lsst-ctrl-mpexec/
.. image:: https://codecov.io/gh/lsst/ctrl_mpexec/branch/main/graph/badge.svg?token=P8UFFVTC4I
 :target: https://codecov.io/gh/lsst/ctrl_mpexec

``ctrl_mpexec`` is a package in the `LSST Science Pipelines <https://pipelines.lsst.io>`_.

It provides a PipelineTask execution framework for single-node processing.

* SPIE paper from 2022: `The Vera C. Rubin Observatory Data Butler and Pipeline Execution System <https://arxiv.org/abs/2206.14941>`_.

PyPI: `lsst-ctrl-mpexec <https://pypi.org/project/lsst-ctrl-mpexec/>`_
